@@ -12,7 +12,7 @@ class Logger:
                 version = 1,
                 formatters={
                     'f': {'format':
-                          '%(levelname)s: %(message)s'}
+                          '\n%(levelname)s: %(message)s'}
                 },
                 handlers={
                     'h': {'class': 'logging.StreamHandler',
